uniform lowp float colordetail;
uniform lowp float pxsize;
uniform lowp float spread;

/////////////////////////////////////////////////////////
// Dithering

//The current foreground texture co-ordinate
varying mediump vec2 vTex;
//The foreground texture sampler, to be sampled at vTex
uniform lowp sampler2D samplerFront;
//The current foreground rectangle being rendered
uniform mediump vec2 srcStart;
uniform mediump vec2 srcEnd;
//The current foreground source rectangle being rendered
uniform mediump vec2 srcOriginStart;
uniform mediump vec2 srcOriginEnd;
//The current foreground source rectangle being rendered, in layout 
uniform mediump vec2 layoutStart;
uniform mediump vec2 layoutEnd;
//The background texture sampler used for background - blending effects
uniform lowp sampler2D samplerBack;
//The current background rectangle being rendered to, in texture co-ordinates, for background-blending effects
uniform mediump vec2 destStart;
uniform mediump vec2 destEnd;
//The time in seconds since the runtime started. This can be used for animated effects
uniform mediump float seconds;
//The size of a texel in the foreground texture in texture co-ordinates
uniform mediump vec2 pixelSize;
//The current layer scale as a factor (i.e. 1 is unscaled)
uniform mediump float layerScale;
//The current layer angle in radians.
uniform mediump float layerAngle;

void main(void)
{
    mediump vec2 iResolution = 1.0 / pixelSize;
    mediump vec2 uv = vTex;
    mediump vec2 srcOriginSize = srcOriginEnd - srcOriginStart;
	mediump vec2 fragCoord = uv * iResolution;
    mediump vec2 texelSize = pxsize/iResolution.xy;
    mediump vec2 pxUV = floor(uv/texelSize)*texelSize;
   
    mediump float x = floor(fragCoord.x/pxsize);
    mediump float y = floor(fragCoord.y/pxsize);

    mediump vec4 curColor = texture2D(samplerFront, pxUV);
    mediump float alpha = curColor.a;
    
    mediump int index = int(mod(x , 2.) + mod(y , 2.) * 2.);
    
    mediump float currentMapValue;
    
    if(index < 3) {
    	currentMapValue = float(index) * 0.25 + 0.25;
    } else {
    	currentMapValue = 0.;
    }
    
    currentMapValue = spread * currentMapValue/4.-0.5;
    
    curColor += 0.5*currentMapValue;
    curColor = floor(curColor*(colordetail-1.)+0.5)/(colordetail-1.);    
    gl_FragColor = curColor * alpha;
}